@@ -1,11 +1,10 @@
 import pytest
 from sphinx.application import Sphinx
 import conftest
-import os
 
 
 def get_tag(tags, tag_type):
-    return [tag for tag in tags if tag.get("property") == "og:{}".format(tag_type)][0]
+    return [tag for tag in tags if tag.get("property") == f"og:{tag_type}"][0]
 
 
 def get_tag_content(tags, tag_type):
@@ -13,6 +12,12 @@ def get_tag_content(tags, tag_type):
     return get_tag(tags, tag_type).get("content", "")
 
 
+def get_meta_description(tags):
+    return [tag for tag in tags if tag.get("name") == "description"][0].get(
+        "content", ""
+    )
+
+
 @pytest.mark.sphinx("html", testroot="simple")
 def test_simple(og_meta_tags):
     description = get_tag_content(og_meta_tags, "description")
@@ -26,6 +31,32 @@ def test_simple(og_meta_tags):
     )
 
 
+@pytest.mark.sphinx("html", testroot="meta-name-description")
+def test_meta_name_description(meta_tags):
+    og_description = get_tag_content(meta_tags, "description")
+    description = get_meta_description(meta_tags)
+
+    assert description == og_description
+
+
+@pytest.mark.sphinx("html", testroot="meta-name-description-manual-description")
+def test_meta_name_description(meta_tags):
+    og_description = get_tag_content(meta_tags, "description")
+    description = get_meta_description(meta_tags)
+
+    assert description != og_description
+    assert description == "My manual description"
+
+
+@pytest.mark.sphinx("html", testroot="meta-name-description-manual-og-description")
+def test_meta_name_description(meta_tags):
+    og_description = get_tag_content(meta_tags, "description")
+    description = get_meta_description(meta_tags)
+
+    assert og_description != description
+    assert og_description == "My manual og:description"
+
+
 @pytest.mark.sphinx("html", testroot="simple")
 def test_site_url(og_meta_tags):
     # Uses the same directory as simple, because it already contains url for a minimal config
@@ -37,7 +68,7 @@ def test_site_url(og_meta_tags):
 
 @pytest.mark.sphinx("dirhtml", testroot="simple")
 def test_dirhtml_url(og_meta_tags):
-    assert get_tag_content(og_meta_tags, "url") == "http://example.org/en/latest/index/"
+    assert get_tag_content(og_meta_tags, "url") == "http://example.org/en/latest/"
 
 
 @pytest.mark.sphinx("html", testroot="image")
